Ported the plug-in to PyQt6 for eric7. eric7

Tue, 01 Jun 2021 17:58:20 +0200

author
Detlev Offenbach <detlev@die-offenbachs.de>
date
Tue, 01 Jun 2021 17:58:20 +0200
branch
eric7
changeset 58
2c8ec39c1d80
parent 57
7c4cb218abde
child 59
7d2c17e9925a

Ported the plug-in to PyQt6 for eric7.

.hgignore file | annotate | diff | comparison | revisions
ChangeLog file | annotate | diff | comparison | revisions
PluginPySide2PyQt.py file | annotate | diff | comparison | revisions
PluginPySide2PyQt.zip file | annotate | diff | comparison | revisions
PySide2PyQt.e4p file | annotate | diff | comparison | revisions
PySide2PyQt.epj file | annotate | diff | comparison | revisions
PySide2PyQt/Documentation/source/Plugin_Tools_PySide2PyQt.PluginPySide2PyQt.html file | annotate | diff | comparison | revisions
PySide2PyQt/i18n/pyside2pyqt_de.qm file | annotate | diff | comparison | revisions
PySide2PyQt/i18n/pyside2pyqt_de.ts file | annotate | diff | comparison | revisions
PySide2PyQt/i18n/pyside2pyqt_empty.ts file | annotate | diff | comparison | revisions
PySide2PyQt/i18n/pyside2pyqt_en.ts file | annotate | diff | comparison | revisions
PySide2PyQt/i18n/pyside2pyqt_es.ts file | annotate | diff | comparison | revisions
PySide2PyQt/i18n/pyside2pyqt_pt.ts file | annotate | diff | comparison | revisions
PySide2PyQt/i18n/pyside2pyqt_ru.ts file | annotate | diff | comparison | revisions
--- a/.hgignore	Tue Jun 01 17:49:53 2021 +0200
+++ b/.hgignore	Tue Jun 01 17:58:20 2021 +0200
@@ -1,11 +1,6 @@
+glob:.eric7project
 glob:.eric6project
-glob:_eric6project
-glob:.eric5project
-glob:_eric5project
-glob:.eric4project
-glob:_eric4project
 glob:.ropeproject
-glob:_ropeproject
 glob:.directory
 glob:**.pyc
 glob:**.pyo
--- a/ChangeLog	Tue Jun 01 17:49:53 2021 +0200
+++ b/ChangeLog	Tue Jun 01 17:58:20 2021 +0200
@@ -1,5 +1,10 @@
 ChangeLog
 ---------
+Version 1.0.0:
+- first release of the eric7 variant
+
+************************************************************
+
 Version 3.1.1:
 - bug fixes
 
--- a/PySide2PyQt.e4p	Tue Jun 01 17:49:53 2021 +0200
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,513 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE Project SYSTEM "Project-5.1.dtd">
-<!-- eric project file for project PySide2PyQt -->
-<!-- Copyright (C) 2020 Detlev Offenbach, detlev@die-offenbachs.de -->
-<Project version="5.1">
-  <Language>en_US</Language>
-  <Hash>d994091d1e81ad5afcdcbc00ecea86f23163c696</Hash>
-  <ProgLanguage mixed="0">Python3</ProgLanguage>
-  <ProjectType>E6Plugin</ProjectType>
-  <Description>Plug-in to convert PySide filePyQt4 and vice versa. It works with the current editor.</Description>
-  <Version>2.x</Version>
-  <Author>Detlev Offenbach</Author>
-  <Email>detlev@die-offenbachs.de</Email>
-  <TranslationPattern>PySide2PyQt/i18n/pyside2pyqt_%language%.ts</TranslationPattern>
-  <Eol index="1"/>
-  <Sources>
-    <Source>PluginPySide2PyQt.py</Source>
-    <Source>PySide2PyQt/__init__.py</Source>
-    <Source>__init__.py</Source>
-  </Sources>
-  <Translations>
-    <Translation>PySide2PyQt/i18n/pyside2pyqt_de.qm</Translation>
-    <Translation>PySide2PyQt/i18n/pyside2pyqt_de.ts</Translation>
-    <Translation>PySide2PyQt/i18n/pyside2pyqt_empty.ts</Translation>
-    <Translation>PySide2PyQt/i18n/pyside2pyqt_en.qm</Translation>
-    <Translation>PySide2PyQt/i18n/pyside2pyqt_en.ts</Translation>
-    <Translation>PySide2PyQt/i18n/pyside2pyqt_es.qm</Translation>
-    <Translation>PySide2PyQt/i18n/pyside2pyqt_es.ts</Translation>
-    <Translation>PySide2PyQt/i18n/pyside2pyqt_pt.qm</Translation>
-    <Translation>PySide2PyQt/i18n/pyside2pyqt_pt.ts</Translation>
-    <Translation>PySide2PyQt/i18n/pyside2pyqt_ru.qm</Translation>
-    <Translation>PySide2PyQt/i18n/pyside2pyqt_ru.ts</Translation>
-  </Translations>
-  <Others>
-    <Other>.hgignore</Other>
-    <Other>ChangeLog</Other>
-    <Other>PKGLIST</Other>
-    <Other>PluginPySide2PyQt.zip</Other>
-    <Other>PySide2PyQt.e4p</Other>
-    <Other>PySide2PyQt/Documentation/LICENSE.GPL3</Other>
-    <Other>PySide2PyQt/Documentation/source</Other>
-  </Others>
-  <MainScript>PluginPySide2PyQt.py</MainScript>
-  <Vcs>
-    <VcsType>Mercurial</VcsType>
-    <VcsOptions>
-      <dict>
-        <key>
-          <string>add</string>
-        </key>
-        <value>
-          <list>
-            <string></string>
-          </list>
-        </value>
-        <key>
-          <string>checkout</string>
-        </key>
-        <value>
-          <list>
-            <string></string>
-          </list>
-        </value>
-        <key>
-          <string>commit</string>
-        </key>
-        <value>
-          <list>
-            <string></string>
-          </list>
-        </value>
-        <key>
-          <string>diff</string>
-        </key>
-        <value>
-          <list>
-            <string></string>
-          </list>
-        </value>
-        <key>
-          <string>export</string>
-        </key>
-        <value>
-          <list>
-            <string></string>
-          </list>
-        </value>
-        <key>
-          <string>global</string>
-        </key>
-        <value>
-          <list>
-            <string></string>
-          </list>
-        </value>
-        <key>
-          <string>history</string>
-        </key>
-        <value>
-          <list>
-            <string></string>
-          </list>
-        </value>
-        <key>
-          <string>log</string>
-        </key>
-        <value>
-          <list>
-            <string></string>
-          </list>
-        </value>
-        <key>
-          <string>remove</string>
-        </key>
-        <value>
-          <list>
-            <string></string>
-          </list>
-        </value>
-        <key>
-          <string>status</string>
-        </key>
-        <value>
-          <list>
-            <string></string>
-          </list>
-        </value>
-        <key>
-          <string>tag</string>
-        </key>
-        <value>
-          <list>
-            <string></string>
-          </list>
-        </value>
-        <key>
-          <string>update</string>
-        </key>
-        <value>
-          <list>
-            <string></string>
-          </list>
-        </value>
-      </dict>
-    </VcsOptions>
-  </Vcs>
-  <FiletypeAssociations>
-    <FiletypeAssociation pattern="*.idl" type="INTERFACES"/>
-    <FiletypeAssociation pattern="*.py" type="SOURCES"/>
-    <FiletypeAssociation pattern="*.py3" type="SOURCES"/>
-    <FiletypeAssociation pattern="*.pyw" type="SOURCES"/>
-    <FiletypeAssociation pattern="*.pyw3" type="SOURCES"/>
-    <FiletypeAssociation pattern="*.qm" type="TRANSLATIONS"/>
-    <FiletypeAssociation pattern="*.qrc" type="RESOURCES"/>
-    <FiletypeAssociation pattern="*.ts" type="TRANSLATIONS"/>
-    <FiletypeAssociation pattern="*.ui" type="FORMS"/>
-  </FiletypeAssociations>
-  <Documentation>
-    <DocumentationParams>
-      <dict>
-        <key>
-          <string>ERIC4DOC</string>
-        </key>
-        <value>
-          <dict>
-            <key>
-              <string>cssFile</string>
-            </key>
-            <value>
-              <string>%PYTHON%/eric6/CSSs/default.css</string>
-            </value>
-            <key>
-              <string>ignoreDirectories</string>
-            </key>
-            <value>
-              <list>
-                <string>.eric5project</string>
-                <string>.hg</string>
-                <string>.ropeproject</string>
-                <string>_eric5project</string>
-                <string>_ropeproject</string>
-                <string>.eric6project</string>
-                <string>_eric6project</string>
-              </list>
-            </value>
-            <key>
-              <string>ignoreFilePatterns</string>
-            </key>
-            <value>
-              <list>
-                <string>Ui_*.py</string>
-              </list>
-            </value>
-            <key>
-              <string>noempty</string>
-            </key>
-            <value>
-              <bool>True</bool>
-            </value>
-            <key>
-              <string>outputDirectory</string>
-            </key>
-            <value>
-              <string>PySide2PyQt/Documentation/source</string>
-            </value>
-            <key>
-              <string>qtHelpEnabled</string>
-            </key>
-            <value>
-              <bool>False</bool>
-            </value>
-            <key>
-              <string>useRecursion</string>
-            </key>
-            <value>
-              <bool>True</bool>
-            </value>
-          </dict>
-        </value>
-      </dict>
-    </DocumentationParams>
-  </Documentation>
-  <Checkers>
-    <CheckersParams>
-      <dict>
-        <key>
-          <string>Pep8Checker</string>
-        </key>
-        <value>
-          <dict>
-            <key>
-              <string>AnnotationsChecker</string>
-            </key>
-            <value>
-              <dict>
-                <key>
-                  <string>MaximumComplexity</string>
-                </key>
-                <value>
-                  <int>3</int>
-                </value>
-                <key>
-                  <string>MinimumCoverage</string>
-                </key>
-                <value>
-                  <int>75</int>
-                </value>
-              </dict>
-            </value>
-            <key>
-              <string>BlankLines</string>
-            </key>
-            <value>
-              <tuple>
-                <int>2</int>
-                <int>1</int>
-              </tuple>
-            </value>
-            <key>
-              <string>BuiltinsChecker</string>
-            </key>
-            <value>
-              <dict>
-                <key>
-                  <string>bytes</string>
-                </key>
-                <value>
-                  <list>
-                    <string>unicode</string>
-                  </list>
-                </value>
-                <key>
-                  <string>chr</string>
-                </key>
-                <value>
-                  <list>
-                    <string>unichr</string>
-                  </list>
-                </value>
-                <key>
-                  <string>str</string>
-                </key>
-                <value>
-                  <list>
-                    <string>unicode</string>
-                  </list>
-                </value>
-              </dict>
-            </value>
-            <key>
-              <string>CommentedCodeChecker</string>
-            </key>
-            <value>
-              <dict>
-                <key>
-                  <string>Aggressive</string>
-                </key>
-                <value>
-                  <bool>False</bool>
-                </value>
-              </dict>
-            </value>
-            <key>
-              <string>CopyrightAuthor</string>
-            </key>
-            <value>
-              <string></string>
-            </value>
-            <key>
-              <string>CopyrightMinFileSize</string>
-            </key>
-            <value>
-              <int>0</int>
-            </value>
-            <key>
-              <string>DocstringType</string>
-            </key>
-            <value>
-              <string>eric</string>
-            </value>
-            <key>
-              <string>EnabledCheckerCategories</string>
-            </key>
-            <value>
-              <string>C, D, E, M, N, S, W</string>
-            </value>
-            <key>
-              <string>ExcludeFiles</string>
-            </key>
-            <value>
-              <string>*/Ui_*.py, */*_rc.py</string>
-            </value>
-            <key>
-              <string>ExcludeMessages</string>
-            </key>
-            <value>
-              <string>C101,E265,E266,E305,E402,M811,N802,N803,N807,N808,N821,W293</string>
-            </value>
-            <key>
-              <string>FixCodes</string>
-            </key>
-            <value>
-              <string></string>
-            </value>
-            <key>
-              <string>FixIssues</string>
-            </key>
-            <value>
-              <bool>False</bool>
-            </value>
-            <key>
-              <string>FutureChecker</string>
-            </key>
-            <value>
-              <string></string>
-            </value>
-            <key>
-              <string>HangClosing</string>
-            </key>
-            <value>
-              <bool>False</bool>
-            </value>
-            <key>
-              <string>IncludeMessages</string>
-            </key>
-            <value>
-              <string></string>
-            </value>
-            <key>
-              <string>LineComplexity</string>
-            </key>
-            <value>
-              <int>20</int>
-            </value>
-            <key>
-              <string>LineComplexityScore</string>
-            </key>
-            <value>
-              <int>10</int>
-            </value>
-            <key>
-              <string>MaxCodeComplexity</string>
-            </key>
-            <value>
-              <int>10</int>
-            </value>
-            <key>
-              <string>MaxDocLineLength</string>
-            </key>
-            <value>
-              <int>79</int>
-            </value>
-            <key>
-              <string>MaxLineLength</string>
-            </key>
-            <value>
-              <int>79</int>
-            </value>
-            <key>
-              <string>NoFixCodes</string>
-            </key>
-            <value>
-              <string>E501</string>
-            </value>
-            <key>
-              <string>RepeatMessages</string>
-            </key>
-            <value>
-              <bool>True</bool>
-            </value>
-            <key>
-              <string>SecurityChecker</string>
-            </key>
-            <value>
-              <dict>
-                <key>
-                  <string>CheckTypedException</string>
-                </key>
-                <value>
-                  <bool>False</bool>
-                </value>
-                <key>
-                  <string>HardcodedTmpDirectories</string>
-                </key>
-                <value>
-                  <list>
-                    <string>/tmp</string>
-                    <string>/var/tmp</string>
-                    <string>/dev/shm</string>
-                    <string>~/tmp</string>
-                  </list>
-                </value>
-                <key>
-                  <string>InsecureHashes</string>
-                </key>
-                <value>
-                  <list>
-                    <string>md4</string>
-                    <string>md5</string>
-                    <string>sha</string>
-                    <string>sha1</string>
-                  </list>
-                </value>
-                <key>
-                  <string>InsecureSslProtocolVersions</string>
-                </key>
-                <value>
-                  <list>
-                    <string>PROTOCOL_SSLv2</string>
-                    <string>SSLv2_METHOD</string>
-                    <string>SSLv23_METHOD</string>
-                    <string>PROTOCOL_SSLv3</string>
-                    <string>PROTOCOL_TLSv1</string>
-                    <string>SSLv3_METHOD</string>
-                    <string>TLSv1_METHOD</string>
-                  </list>
-                </value>
-                <key>
-                  <string>WeakKeySizeDsaHigh</string>
-                </key>
-                <value>
-                  <string>1024</string>
-                </value>
-                <key>
-                  <string>WeakKeySizeDsaMedium</string>
-                </key>
-                <value>
-                  <string>2048</string>
-                </value>
-                <key>
-                  <string>WeakKeySizeEcHigh</string>
-                </key>
-                <value>
-                  <string>160</string>
-                </value>
-                <key>
-                  <string>WeakKeySizeEcMedium</string>
-                </key>
-                <value>
-                  <string>224</string>
-                </value>
-                <key>
-                  <string>WeakKeySizeRsaHigh</string>
-                </key>
-                <value>
-                  <string>1024</string>
-                </value>
-                <key>
-                  <string>WeakKeySizeRsaMedium</string>
-                </key>
-                <value>
-                  <string>2048</string>
-                </value>
-              </dict>
-            </value>
-            <key>
-              <string>ShowIgnored</string>
-            </key>
-            <value>
-              <bool>False</bool>
-            </value>
-            <key>
-              <string>ValidEncodings</string>
-            </key>
-            <value>
-              <string>latin-1, utf-8</string>
-            </value>
-          </dict>
-        </value>
-      </dict>
-    </CheckersParams>
-  </Checkers>
-</Project>
--- a/PySide2PyQt.epj	Tue Jun 01 17:49:53 2021 +0200
+++ b/PySide2PyQt.epj	Tue Jun 01 17:58:20 2021 +0200
@@ -113,15 +113,12 @@
     "DOCSTRING": "",
     "DOCUMENTATIONPARMS": {
       "ERIC4DOC": {
-        "cssFile": "%PYTHON%/eric6/CSSs/default.css",
+        "cssFile": "%PYTHON%/eric7/CSSs/default.css",
         "ignoreDirectories": [
-          ".eric5project",
           ".hg",
           ".ropeproject",
-          "_eric5project",
-          "_ropeproject",
           ".eric6project",
-          "_eric6project"
+          ".eric7project"
         ],
         "ignoreFilePatterns": [
           "Ui_*.py"
@@ -135,15 +132,25 @@
     "EMAIL": "detlev@die-offenbachs.de",
     "EOL": 1,
     "FILETYPES": {
+      "*.epj": "OTHERS",
       "*.idl": "INTERFACES",
+      "*.md": "OTHERS",
+      "*.proto": "PROTOCOLS",
       "*.py": "SOURCES",
       "*.py3": "SOURCES",
       "*.pyw": "SOURCES",
       "*.pyw3": "SOURCES",
       "*.qm": "TRANSLATIONS",
-      "*.qrc": "RESOURCES",
+      "*.rst": "OTHERS",
       "*.ts": "TRANSLATIONS",
-      "*.ui": "FORMS"
+      "*.txt": "OTHERS",
+      "*.ui": "FORMS",
+      "GNUmakefile": "OTHERS",
+      "Makefile": "OTHERS",
+      "README": "OTHERS",
+      "README.*": "OTHERS",
+      "Ui_*.py": "__IGNORE__",
+      "makefile": "OTHERS"
     },
     "FORMS": [],
     "HASH": "d994091d1e81ad5afcdcbc00ecea86f23163c696",
@@ -169,7 +176,6 @@
       "ChangeLog",
       "PKGLIST",
       "PluginPySide2PyQt.zip",
-      "PySide2PyQt.e4p",
       "PySide2PyQt/Documentation/LICENSE.GPL3",
       "PySide2PyQt/Documentation/source",
       "PySide2PyQt.epj"
@@ -177,7 +183,7 @@
     "OTHERTOOLSPARMS": {},
     "PACKAGERSPARMS": {},
     "PROGLANGUAGE": "Python3",
-    "PROJECTTYPE": "E6Plugin",
+    "PROJECTTYPE": "E7Plugin",
     "PROJECTTYPESPECIFICDATA": {},
     "PROTOCOLS": [],
     "RCCPARAMS": {
@@ -256,6 +262,6 @@
       ]
     },
     "VCSOTHERDATA": {},
-    "VERSION": "2.x"
+    "VERSION": ""
   }
 }
\ No newline at end of file
--- a/PySide2PyQt/Documentation/source/Plugin_Tools_PySide2PyQt.PluginPySide2PyQt.html	Tue Jun 01 17:49:53 2021 +0200
+++ b/PySide2PyQt/Documentation/source/Plugin_Tools_PySide2PyQt.PluginPySide2PyQt.html	Tue Jun 01 17:58:20 2021 +0200
@@ -128,9 +128,9 @@
 </p>
 <dl>
 
-<dt><i>ui</i></dt>
+<dt><i>ui</i> (UserInterface)</dt>
 <dd>
-reference to the user interface object (UI.UserInterface)
+reference to the user interface object
 </dd>
 </dl>
 <a NAME="PySide2PyQtPlugin.__editorClosed" ID="PySide2PyQtPlugin.__editorClosed"></a>
@@ -142,9 +142,9 @@
 </p>
 <dl>
 
-<dt><i>editor</i></dt>
+<dt><i>editor</i> (Editor)</dt>
 <dd>
-reference to the editor (QScintilla.Editor)
+reference to the editor
 </dd>
 </dl>
 <a NAME="PySide2PyQtPlugin.__editorOpened" ID="PySide2PyQtPlugin.__editorOpened"></a>
@@ -156,9 +156,9 @@
 </p>
 <dl>
 
-<dt><i>editor</i></dt>
+<dt><i>editor</i> (Editor)</dt>
 <dd>
-reference to the new editor (QScintilla.Editor)
+reference to the new editor
 </dd>
 </dl>
 <a NAME="PySide2PyQtPlugin.__editorShowMenu" ID="PySide2PyQtPlugin.__editorShowMenu"></a>
@@ -171,15 +171,15 @@
 </p>
 <dl>
 
-<dt><i>menuName</i></dt>
+<dt><i>menuName</i> (str)</dt>
 <dd>
-name of the menu to be shown (string)
+name of the menu to be shown
 </dd>
-<dt><i>menu</i></dt>
+<dt><i>menu</i> (QMenu)</dt>
 <dd>
-reference to the menu (QMenu)
+reference to the menu
 </dd>
-<dt><i>editor</i></dt>
+<dt><i>editor</i> (Editor)</dt>
 <dd>
 reference to the editor
 </dd>
@@ -207,13 +207,13 @@
 </p>
 <dl>
 
-<dt><i>name</i></dt>
+<dt><i>name</i> (str)</dt>
 <dd>
-name of the menu (string)
+name of the menu
 </dd>
-<dt><i>menu</i></dt>
+<dt><i>menu</i> (QMenu)</dt>
 <dd>
-reference to the menu to be populated (QMenu)
+reference to the menu to be populated
 </dd>
 </dl>
 <a NAME="PySide2PyQtPlugin.__pyqt2Pyside" ID="PySide2PyQtPlugin.__pyqt2Pyside"></a>
@@ -228,11 +228,11 @@
 
 <dt><i>pyqt</i> (str)</dt>
 <dd>
-PyQt variant (pyqt5)
+PyQt variant (pyqt5 or pyqt6)
 </dd>
 <dt><i>pyside</i> (str)</dt>
 <dd>
-PySide variant (pyside2)
+PySide variant (pyside2 or pyside6)
 </dd>
 </dl>
 <a NAME="PySide2PyQtPlugin.__pyside2Pyqt" ID="PySide2PyQtPlugin.__pyside2Pyqt"></a>
@@ -247,11 +247,11 @@
 
 <dt><i>pyside</i> (str)</dt>
 <dd>
-PySide variant (pyside2)
+PySide variant (pyside2 or pyside6)
 </dd>
 <dt><i>pyqt</i> (str)</dt>
 <dd>
-PyQt variant (pyqt5)
+PyQt variant (pyqt5 or pyqt6)
 </dd>
 </dl>
 <a NAME="PySide2PyQtPlugin.activate" ID="PySide2PyQtPlugin.activate"></a>
@@ -264,7 +264,13 @@
 <dl>
 <dt>Return:</dt>
 <dd>
-tuple of None and activation status (boolean)
+tuple of None and activation status
+</dd>
+</dl>
+<dl>
+<dt>Return Type:</dt>
+<dd>
+(None, bool)
 </dd>
 </dl>
 <a NAME="PySide2PyQtPlugin.deactivate" ID="PySide2PyQtPlugin.deactivate"></a>
Binary file PySide2PyQt/i18n/pyside2pyqt_de.qm has changed
--- a/PySide2PyQt/i18n/pyside2pyqt_de.ts	Tue Jun 01 17:49:53 2021 +0200
+++ b/PySide2PyQt/i18n/pyside2pyqt_de.ts	Tue Jun 01 17:58:20 2021 +0200
@@ -1,21 +1,32 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="de_DE" sourcelanguage="">
-<context>
+<!DOCTYPE TS>
+<TS version="2.1" language="de_DE">
+  <context>
     <name>PySide2PyQtPlugin</name>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="136"/>
-        <source>PySide to/from PyQt</source>
-        <translation>PySide von/nach PyQt</translation>
+      <location filename="../../PluginPySide2PyQt.py" line="140" />
+      <source>PySide to/from PyQt</source>
+      <translation>PySide von/nach PyQt</translation>
+    </message>
+    <message>
+      <location filename="../../PluginPySide2PyQt.py" line="141" />
+      <source>PySide2 to PyQt5</source>
+      <translation>PySide2 nach PyQt5</translation>
     </message>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="137"/>
-        <source>PySide2 to PyQt5</source>
-        <translation>PySide2 nach PyQt5</translation>
+      <location filename="../../PluginPySide2PyQt.py" line="143" />
+      <source>PyQt5 to PySide2</source>
+      <translation>PyQt5 nach PySide2</translation>
     </message>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="140"/>
-        <source>PyQt5 to PySide2</source>
-        <translation>PyQt5 nach PySide2</translation>
+      <location filename="../../PluginPySide2PyQt.py" line="146" />
+      <source>PySide6 to PyQt6</source>
+      <translation>PySide6 nach PyQt6</translation>
     </message>
-</context>
+    <message>
+      <location filename="../../PluginPySide2PyQt.py" line="148" />
+      <source>PyQt6 to PySide6</source>
+      <translation>PyQt6 nach PySide6</translation>
+    </message>
+  </context>
 </TS>
--- a/PySide2PyQt/i18n/pyside2pyqt_empty.ts	Tue Jun 01 17:49:53 2021 +0200
+++ b/PySide2PyQt/i18n/pyside2pyqt_empty.ts	Tue Jun 01 17:58:20 2021 +0200
@@ -1,21 +1,32 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0">
-<context>
+<!DOCTYPE TS>
+<TS version="2.0">
+  <context>
     <name>PySide2PyQtPlugin</name>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="136"/>
-        <source>PySide to/from PyQt</source>
-        <translation type="unfinished"></translation>
+      <location filename="../../PluginPySide2PyQt.py" line="140" />
+      <source>PySide to/from PyQt</source>
+      <translation type="unfinished" />
+    </message>
+    <message>
+      <location filename="../../PluginPySide2PyQt.py" line="141" />
+      <source>PySide2 to PyQt5</source>
+      <translation type="unfinished" />
     </message>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="137"/>
-        <source>PySide2 to PyQt5</source>
-        <translation type="unfinished"></translation>
+      <location filename="../../PluginPySide2PyQt.py" line="143" />
+      <source>PyQt5 to PySide2</source>
+      <translation type="unfinished" />
     </message>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="140"/>
-        <source>PyQt5 to PySide2</source>
-        <translation type="unfinished"></translation>
+      <location filename="../../PluginPySide2PyQt.py" line="146" />
+      <source>PySide6 to PyQt6</source>
+      <translation type="unfinished" />
     </message>
-</context>
+    <message>
+      <location filename="../../PluginPySide2PyQt.py" line="148" />
+      <source>PyQt6 to PySide6</source>
+      <translation type="unfinished" />
+    </message>
+  </context>
 </TS>
--- a/PySide2PyQt/i18n/pyside2pyqt_en.ts	Tue Jun 01 17:49:53 2021 +0200
+++ b/PySide2PyQt/i18n/pyside2pyqt_en.ts	Tue Jun 01 17:58:20 2021 +0200
@@ -1,21 +1,32 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="en_US" sourcelanguage="">
-<context>
+<!DOCTYPE TS>
+<TS version="2.0" language="en_US" sourcelanguage="">
+  <context>
     <name>PySide2PyQtPlugin</name>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="136"/>
-        <source>PySide to/from PyQt</source>
-        <translation type="unfinished"></translation>
+      <location filename="../../PluginPySide2PyQt.py" line="140" />
+      <source>PySide to/from PyQt</source>
+      <translation type="unfinished" />
+    </message>
+    <message>
+      <location filename="../../PluginPySide2PyQt.py" line="141" />
+      <source>PySide2 to PyQt5</source>
+      <translation type="unfinished" />
     </message>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="137"/>
-        <source>PySide2 to PyQt5</source>
-        <translation type="unfinished"></translation>
+      <location filename="../../PluginPySide2PyQt.py" line="143" />
+      <source>PyQt5 to PySide2</source>
+      <translation type="unfinished" />
     </message>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="140"/>
-        <source>PyQt5 to PySide2</source>
-        <translation type="unfinished"></translation>
+      <location filename="../../PluginPySide2PyQt.py" line="146" />
+      <source>PySide6 to PyQt6</source>
+      <translation type="unfinished" />
     </message>
-</context>
+    <message>
+      <location filename="../../PluginPySide2PyQt.py" line="148" />
+      <source>PyQt6 to PySide6</source>
+      <translation type="unfinished" />
+    </message>
+  </context>
 </TS>
--- a/PySide2PyQt/i18n/pyside2pyqt_es.ts	Tue Jun 01 17:49:53 2021 +0200
+++ b/PySide2PyQt/i18n/pyside2pyqt_es.ts	Tue Jun 01 17:58:20 2021 +0200
@@ -1,21 +1,32 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="es_ES" sourcelanguage="">
-<context>
+<!DOCTYPE TS>
+<TS version="2.0" language="es_ES" sourcelanguage="">
+  <context>
     <name>PySide2PyQtPlugin</name>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="136"/>
-        <source>PySide to/from PyQt</source>
-        <translation>PySide a/desde PyQt</translation>
+      <location filename="../../PluginPySide2PyQt.py" line="140" />
+      <source>PySide to/from PyQt</source>
+      <translation>PySide a/desde PyQt</translation>
+    </message>
+    <message>
+      <location filename="../../PluginPySide2PyQt.py" line="141" />
+      <source>PySide2 to PyQt5</source>
+      <translation type="unfinished" />
     </message>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="137"/>
-        <source>PySide2 to PyQt5</source>
-        <translation type="unfinished"></translation>
+      <location filename="../../PluginPySide2PyQt.py" line="143" />
+      <source>PyQt5 to PySide2</source>
+      <translation type="unfinished" />
     </message>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="140"/>
-        <source>PyQt5 to PySide2</source>
-        <translation type="unfinished"></translation>
+      <location filename="../../PluginPySide2PyQt.py" line="146" />
+      <source>PySide6 to PyQt6</source>
+      <translation type="unfinished" />
     </message>
-</context>
+    <message>
+      <location filename="../../PluginPySide2PyQt.py" line="148" />
+      <source>PyQt6 to PySide6</source>
+      <translation type="unfinished" />
+    </message>
+  </context>
 </TS>
--- a/PySide2PyQt/i18n/pyside2pyqt_pt.ts	Tue Jun 01 17:49:53 2021 +0200
+++ b/PySide2PyQt/i18n/pyside2pyqt_pt.ts	Tue Jun 01 17:58:20 2021 +0200
@@ -1,21 +1,32 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="en_US" sourcelanguage="">
-<context>
+<!DOCTYPE TS>
+<TS version="2.0" language="en_US" sourcelanguage="">
+  <context>
     <name>PySide2PyQtPlugin</name>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="136"/>
-        <source>PySide to/from PyQt</source>
-        <translation>PySide de/a PyQt</translation>
+      <location filename="../../PluginPySide2PyQt.py" line="140" />
+      <source>PySide to/from PyQt</source>
+      <translation>PySide de/a PyQt</translation>
+    </message>
+    <message>
+      <location filename="../../PluginPySide2PyQt.py" line="141" />
+      <source>PySide2 to PyQt5</source>
+      <translation type="unfinished" />
     </message>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="137"/>
-        <source>PySide2 to PyQt5</source>
-        <translation type="unfinished"></translation>
+      <location filename="../../PluginPySide2PyQt.py" line="143" />
+      <source>PyQt5 to PySide2</source>
+      <translation type="unfinished" />
     </message>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="140"/>
-        <source>PyQt5 to PySide2</source>
-        <translation type="unfinished"></translation>
+      <location filename="../../PluginPySide2PyQt.py" line="146" />
+      <source>PySide6 to PyQt6</source>
+      <translation type="unfinished" />
     </message>
-</context>
+    <message>
+      <location filename="../../PluginPySide2PyQt.py" line="148" />
+      <source>PyQt6 to PySide6</source>
+      <translation type="unfinished" />
+    </message>
+  </context>
 </TS>
--- a/PySide2PyQt/i18n/pyside2pyqt_ru.ts	Tue Jun 01 17:49:53 2021 +0200
+++ b/PySide2PyQt/i18n/pyside2pyqt_ru.ts	Tue Jun 01 17:58:20 2021 +0200
@@ -1,21 +1,32 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="ru_RU" sourcelanguage="">
-<context>
+<!DOCTYPE TS>
+<TS version="2.0" language="ru_RU" sourcelanguage="">
+  <context>
     <name>PySide2PyQtPlugin</name>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="136"/>
-        <source>PySide to/from PyQt</source>
-        <translation>PySide в/из PyQt</translation>
+      <location filename="../../PluginPySide2PyQt.py" line="140" />
+      <source>PySide to/from PyQt</source>
+      <translation>PySide в/из PyQt</translation>
+    </message>
+    <message>
+      <location filename="../../PluginPySide2PyQt.py" line="141" />
+      <source>PySide2 to PyQt5</source>
+      <translation>PySide2 в PyQt5</translation>
     </message>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="137"/>
-        <source>PySide2 to PyQt5</source>
-        <translation>PySide2 в PyQt5</translation>
+      <location filename="../../PluginPySide2PyQt.py" line="143" />
+      <source>PyQt5 to PySide2</source>
+      <translation>PyQt5 в PySide2</translation>
     </message>
     <message>
-        <location filename="../../PluginPySide2PyQt.py" line="140"/>
-        <source>PyQt5 to PySide2</source>
-        <translation>PyQt5 в PySide2</translation>
+      <location filename="../../PluginPySide2PyQt.py" line="146" />
+      <source>PySide6 to PyQt6</source>
+      <translation type="unfinished" />
     </message>
-</context>
+    <message>
+      <location filename="../../PluginPySide2PyQt.py" line="148" />
+      <source>PyQt6 to PySide6</source>
+      <translation type="unfinished" />
+    </message>
+  </context>
 </TS>

eric ide

mercurial
--- a/PluginPySide2PyQt.py	Tue Jun 01 17:49:53 2021 +0200
+++ b/PluginPySide2PyQt.py	Tue Jun 01 17:58:20 2021 +0200
@@ -10,23 +10,24 @@
 import contextlib
 import os
 
-from PyQt5.QtCore import QObject, QTranslator
-from PyQt5.QtWidgets import QMenu
+from PyQt6.QtCore import QObject, QTranslator
+from PyQt6.QtWidgets import QMenu
 
-from E5Gui.E5Application import e5App
+from EricWidgets.EricApplication import ericApp
 
 # Start-Of-Header
 name = "PySide to PyQt (and vice versa) Plug-in"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "3.1.1"
+version = "1.0.0"
 className = "PySide2PyQtPlugin"
 packageName = "PySide2PyQt"
 shortDescription = "Convert PySide file to PyQt and vice versa"
 longDescription = (
     """This plug-in implements a tool to convert a PySide2 file to PyQt5"""
     """ and vice versa. It works with the text of the current editor."""
 )
 needsRestart = False
 pyqtApi = 2
@@ -43,7 +44,8 @@
         """
         Constructor
         
-        @param ui reference to the user interface object (UI.UserInterface)
+        @param ui reference to the user interface object
+        @type UserInterface
         """
         super().__init__(ui)
         self.__ui = ui
@@ -60,7 +62,8 @@
         """
         Public method to activate this plugin.
         
-        @return tuple of None and activation status (boolean)
+        @return tuple of None and activation status
+        @rtype (None, bool)
         """
         global error
         error = ""     # clear previous error
@@ -75,12 +78,12 @@
             act = menu.addMenu(self.__menu)
             self.__mainActions.append(act)
         
-        e5App().getObject("ViewManager").editorOpenedEd.connect(
+        ericApp().getObject("ViewManager").editorOpenedEd.connect(
             self.__editorOpened)
-        e5App().getObject("ViewManager").editorClosedEd.connect(
+        ericApp().getObject("ViewManager").editorClosedEd.connect(
             self.__editorClosed)
         
-        for editor in e5App().getObject("ViewManager").getOpenEditors():
+        for editor in ericApp().getObject("ViewManager").getOpenEditors():
             self.__editorOpened(editor)
         
         return None, True
@@ -97,9 +100,9 @@
                 menu.removeAction(act)
         self.__mainActions = []
 
-        e5App().getObject("ViewManager").editorOpenedEd.disconnect(
+        ericApp().getObject("ViewManager").editorOpenedEd.disconnect(
             self.__editorOpened)
-        e5App().getObject("ViewManager").editorClosedEd.disconnect(
+        ericApp().getObject("ViewManager").editorClosedEd.disconnect(
             self.__editorClosed)
         
         for editor, acts in self.__editors.items():
@@ -124,7 +127,7 @@
                 loaded = translator.load(translation, locale_dir)
                 if loaded:
                     self.__translator = translator
-                    e5App().installTranslator(self.__translator)
+                    ericApp().installTranslator(self.__translator)
                 else:
                     print("Warning: translation file '{0}' could not be"
                           " loaded.".format(translation))
@@ -137,22 +140,28 @@
         self.__menu = QMenu(self.tr("PySide to/from PyQt"))
         self.__menu.addAction(self.tr("PySide2 to PyQt5"),
                               lambda: self.__pyside2Pyqt("pyside2", "pyqt5"))
-        self.__menu.addSeparator()
         self.__menu.addAction(self.tr("PyQt5 to PySide2"),
                               lambda: self.__pyqt2Pyside("pyqt5", "pyside2"))
+        self.__menu.addSeparator()
+        self.__menu.addAction(self.tr("PySide6 to PyQt6"),
+                              lambda: self.__pyside2Pyqt("pyside6", "pyqt6"))
+        self.__menu.addAction(self.tr("PyQt6 to PySide6"),
+                              lambda: self.__pyqt2Pyside("pyqt6", "pyside6"))
         self.__menu.setEnabled(False)
     
     def __populateMenu(self, name, menu):
         """
         Private slot to populate the tools menu with our entries.
         
-        @param name name of the menu (string)
-        @param menu reference to the menu to be populated (QMenu)
+        @param name name of the menu
+        @type str
+        @param menu reference to the menu to be populated
+        @type QMenu
         """
         if name not in ["Tools", "PluginTools"]:
             return
         
-        editor = e5App().getObject("ViewManager").activeWindow()
+        editor = ericApp().getObject("ViewManager").activeWindow()
         
         if name == "Tools":
             if not menu.isEmpty():
@@ -166,7 +175,8 @@
         """
         Private slot called, when a new editor was opened.
         
-        @param editor reference to the new editor (QScintilla.Editor)
+        @param editor reference to the new editor
+        @type Editor
         """
         menu = editor.getMenu("Tools")
         if menu is not None:
@@ -183,7 +193,8 @@
         """
         Private slot called, when an editor was closed.
         
-        @param editor reference to the editor (QScintilla.Editor)
+        @param editor reference to the editor
+        @type Editor
         """
         with contextlib.suppress(KeyError):
             del self.__editors[editor]
@@ -195,9 +206,12 @@
         Private slot called, when the the editor context menu or a submenu is
         about to be shown.
         
-        @param menuName name of the menu to be shown (string)
-        @param menu reference to the menu (QMenu)
+        @param menuName name of the menu to be shown
+        @type str
+        @param menu reference to the menu
+        @type QMenu
         @param editor reference to the editor
+        @type Editor
         """
         if (
             menuName == "Tools" and
@@ -216,12 +230,12 @@
         Private slot to convert the code of the current editor from PySide
         to PyQt.
         
-        @param pyside PySide variant (pyside2)
+        @param pyside PySide variant (pyside2 or pyside6)
         @type str
-        @param pyqt PyQt variant (pyqt5)
+        @param pyqt PyQt variant (pyqt5 or pyqt6)
         @type str
         """
-        editor = e5App().getObject("ViewManager").activeWindow()
+        editor = ericApp().getObject("ViewManager").activeWindow()
         if editor is None:
             return
         
@@ -229,14 +243,24 @@
         if pyqt == "pyqt5" and pyside == "pyside2":
             newText = (
                 text
+                .replace("PySide2", "PyQt5")
                 .replace("Signal", "pyqtSignal")
                 .replace("Slot", "pyqtSlot")
                 .replace("Property", "pyqtProperty")
-                .replace("PySide2", "PyQt5")
                 .replace("pyside2-uic", "pyuic5")
                 .replace("pyside2-rcc", "pyrcc5")
                 .replace("pyside2-lupdate", "pylupdate5")
             )
+        elif pyqt == "pyqt6" and pyside == "pyside6":
+            newText = (
+                text
+                .replace("PySide6", "PyQt6")
+                .replace("Signal", "pyqtSignal")
+                .replace("Slot", "pyqtSlot")
+                .replace("Property", "pyqtProperty")
+                .replace("pyside6-uic", "pyuic6")
+                .replace("pyside6-lupdate", "pylupdate6")
+            )
         else:
             return
         
@@ -251,12 +275,12 @@
         Private slot to convert the code of the current editor from PyQt
         to PySide.
         
-        @param pyqt PyQt variant (pyqt5)
+        @param pyqt PyQt variant (pyqt5 or pyqt6)
         @type str
-        @param pyside PySide variant (pyside2)
+        @param pyside PySide variant (pyside2 or pyside6)
         @type str
         """
-        editor = e5App().getObject("ViewManager").activeWindow()
+        editor = ericApp().getObject("ViewManager").activeWindow()
         if editor is None:
             return
         
@@ -272,6 +296,16 @@
                 .replace("pyrcc5", "pyside2-rcc")
                 .replace("pylupdate5", "pyside2-lupdate")
             )
+        elif pyqt == "pyqt6" and pyside == "pyside6":
+            newText = (
+                text
+                .replace("PyQt6", "PySide6")
+                .replace("pyqtSignal", "Signal")
+                .replace("pyqtSlot", "Slot")
+                .replace("pyqtProperty", "Property")
+                .replace("pyuic6", "pyside6-uic")
+                .replace("pylupdate6", "pyside6-lupdate")
+            )
         else:
             return
         
@@ -10,23 +10,24 @@
 longDescription = (
     """This plug-in implements a tool to convert a PySide2 file to PyQt5"""
-    """ and vice versa. It works with the text of the current editor."""
+    """ and vice versa or a PySide6 file to PyQt6 and vice versa. It works"""
+    """ with the text of the current editor."""
 )
 needsRestart = False
Binary file PluginPySide2PyQt.zip has changed